pub struct DataSquare {
pub square_row: Matrix3D,
pub square_col: Matrix3D,
pub width: usize,
pub original_width: usize,
pub chunk_size: usize,
pub row_roots: Matrix2D,
pub col_roots: Matrix2D,
pub codec: Box<dyn Codec>,
}Expand description
Store all data for an original data square (ODS) or extended data square (EDS). Data is duplicated in both row-major and column-major order in order to be able to provide zero-allocation column slices.
Fields
square_row: Matrix3Dsquare_col: Matrix3Dwidth: usizeoriginal_width: usizechunk_size: usizerow_roots: Matrix2Dcol_roots: Matrix2Dcodec: Box<dyn Codec>Implementations